@@ -178,11 +178,11 @@ class GraphQLRemoteExecutor(GraphQLBaseExecutor, GraphQLObjectType):
         )
 
     def execute(
-            self,
-            query,
-            variable_values=None,
-            operation_name=None,
-            http_headers=None
+        self,
+        query,
+        variable_values=None,
+        operation_name=None,
+        http_headers=None
     ) -> ExecutionResult:
 
         if http_headers is None:
@@ -318,6 +318,9 @@ class GraphQLRemoteObject:
         if not delay_mapping:
             self._map()
 
+    def clear_cache(self):
+        self.values.clear()
+
     def _map(self, force=False):
         if self.mappers is None:
             api = self.api
